@@ -1,6 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 1998-2000, 2008, 2010, 2012, 2016-2018 Sergey
-   Poznyakoff
+   Copyright (C) 1998-2019 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -519,7 +518,7 @@ set_log_facility(enum grecs_callback_command cmd,
 }
 
 static int
-cmp_modinst_ident(const void *item, void *data)
+cmp_modinst_ident(const void *item, const void *data, void *closure)
 {
     const dicod_module_instance_t *inst = item;
     if (!inst->ident)
@@ -589,7 +588,7 @@ load_module_cb(enum grecs_callback_command cmd,
 }
 
 static int
-cmp_database_name(const void *item, void *data)
+cmp_database_name(const void *item, const void *data, void *closure)
 {
     const dicod_database_t *db = item;
     int rc;
@@ -633,23 +632,13 @@ set_database(enum grecs_callback_command cmd,
 	    return 1;
 	}
 	
-	if (dict->extra) {
-  	    if (strcmp(dict->instance->ident, "virtual")) {
-		grecs_error(locus, 0,
-	                    _("expected handler \"virtual\", but found \"%s\""),
-	                    dict->instance->ident);
-		dicod_database_free(dict);
-		return 1;
-	    }
-	}
-
 	if (!database_list) {
 	    database_list = xdico_list_create();
-	    dico_list_set_comparator (database_list, cmp_database_name);
+	    dico_list_set_comparator (database_list, cmp_database_name, NULL);
 	}
 	if (dict->langlist[0] || dict->langlist[1])
 	     /* Prevent dico_db_lang from being called */
-	    dict->flags |= DICOD_DBF_LANG;
+	    dict->flags |= DICO_DBF_LANG;
 
 	xdico_list_append(database_list, dict);
 	*pdata = NULL;
@@ -1089,7 +1078,8 @@ strategy_cb(enum grecs_callback_command cmd,
 		if (!strat_forward) {
 		    strat_forward = xdico_list_create();
 		    dico_list_set_comparator (strat_forward,
-					      dico_strat_name_cmp);
+					      dico_strat_name_cmp,
+					      NULL);
 		    dico_list_set_free_item(strat_forward,
 					    dico_strat_free, NULL);
 		}
@@ -1444,7 +1434,7 @@ config_init(void)
     grecs_parser_options = GRECS_OPTION_QUOTED_STRING_CONCAT;
 
     modinst_list = xdico_list_create();
-    dico_list_set_comparator(modinst_list, cmp_modinst_ident);
+    dico_list_set_comparator(modinst_list, cmp_modinst_ident, NULL);
 
     dicod_builtin_module_init();
 }
