@@ -1,5 +1,5 @@
 /* This file is part of Dico.
-   Copyright (C) 2008-2018 Sergey Poznyakoff
+   Copyright (C) 2008-2019 Sergey Poznyakoff
 
    Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ dicod_mime(dico_stream_t str, int argc, char **argv)
 }
 
 void
-register_mime()
+register_mime(void)
 {
     static struct dicod_command cmd[] = {
 	{ "OPTION MIME", 2, 2, NULL, "use MIME headers",
