@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 2008-2018 Sergey Poznyakoff
+   Copyright (C) 2008-2019 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 struct dico_stat current_stat, total_stat;
 
 void
-clear_stats()
+clear_stats(void)
 {
     total_stat.defines += current_stat.defines;
     total_stat.matches += current_stat.matches;
